@@ -297,9 +297,9 @@ int miniterm = 0;
   int multlist = 0;
   int max_multipliers;
   int mult_bands[MAX_MULTS];
-  char callmasterarray[28000][9];
+  char callmasterarray[MAX_CALLMASTER][9];
   char callmaster_result[50][9];
-  int max_callmastercalls;
+  long int max_callmastercalls;
   int callareas[20];
   int multscore[NBANDS];
 
