@@ -237,6 +237,7 @@ extern char controllerport[80];		// port for multi-mode controller
 extern char clusterlogin[];
 extern int cw_bandwidth;
 extern int nobandchange;
+extern int change_rst;
 
 
 
@@ -390,7 +391,7 @@ extern int nobandchange;
 		"LOWBAND_DOUBLE",		/* 145 */
 		"CLUSTER_LOG",
 		"SERIAL+GRID4",
-		"",
+		"CHANGE_RST",
 		""
 		
 	};
@@ -1176,6 +1177,10 @@ extern int nobandchange;
 					serial_grid4_mult = 1;
 					break;
 			}
+			case 148 : {
+					change_rst = 1;
+					break;
+			}
 
 		}
 
