@@ -89,8 +89,12 @@
 		{
 			strncpy(buffer, buf, 79);
 
-			buffer[strlen(buffer)-1] = '\0';            // remove     \012
-			buffer[strlen(buffer)-1] = '\0';           // remove      \015
+	  		char *loc = NULL;						//PG4I, 26Jul2005
+	  		if ((loc = strchr(buffer, '\r')))
+	   		*loc = '\0';
+
+//			buffer[strlen(buffer)-1] = '\0';            // remove     \012
+//			buffer[strlen(buffer)-1] = '\0';           // remove      \015
 
  			n = strlen(buffer);
 
