@@ -26,6 +26,8 @@
 #	include <config.h>
 #endif
 
+static char searchresult[MAX_CALLS][82];
+static char result[MAX_CALLS][82];
 
  	int searchlog(char *searchstring)
 
@@ -64,24 +66,27 @@
 	extern int mixedmode;
 	extern int qso_once;
 	extern int trxmode;
-	extern int max_callmastercalls;
-	extern char callmasterarray[28000][9];
+	extern long int max_callmastercalls;
+	extern char callmasterarray[MAX_CALLMASTER][9];
 	extern char qsos[MAX_QSOS][82];
 	extern char hiscall[];
 	extern char zone_export[];
 	extern char zone_fix[];
 	extern int show_time;
+    extern int wazmult;
+    extern int itumult;
 
 
-char searchresult[MAX_CALLS][82];
+//char searchresult[MAX_CALLS][82];
 int srch_index=0;
-char result[MAX_CALLS][82];
+//char result[MAX_CALLS][82];
 int r_index=0;
 char s_inputbuffer[82] =  "";
 char s_inputbuffercpy[82] =  "";
-static 	char zonebuffer[3] = "";
-static 	int z, z1;
-static 	int i, j, k, l, m;
+static char zonebuffer[3] = "";
+static int z, z1;
+static int i, j, k, l; 
+static long int m;
 static int pxnr;
 static int qso_index = 0;
 
@@ -89,15 +94,23 @@ char *tmpstr;
 
 char callmaster_location[80];
 
-strcpy(callmaster_location, PACKAGE_DATA_DIR) ;
-strcat(callmaster_location, "/callmaster ") ;
+#if 0
+		if (strlen(s_inputbuffer)>=83)
+	{
+		printf ("WARNING: Input buffer is longer than 82 characters! exiting...");
+		exit(1);
+	}
+#endif
+	strcpy(callmaster_location, PACKAGE_DATA_DIR) ;
+	strcat(callmaster_location, "/callmaster ") ;
 
 	l=0;
 	z = 0;
 	s_inputbuffer[0] = '\0';
 	zonebuffer[0] = '\0';
  	
- 	if (strlen(hiscall) > 1 && searchflg  == SEARCHWINDOW){
+ 	if (strlen(hiscall) > 1 && searchflg  == SEARCHWINDOW)
+	{
 
  	    if (strlen(hiscall) == 2)
  	    	z1 = 0;
@@ -116,13 +129,15 @@ strcat(callmaster_location, "/callmaster ") ;
 
 //
 
-		while (strlen(qsos[qso_index]) > 2)  {
+		while (strlen(qsos[qso_index]) > 2)
+		{
 
 			strncpy(s_inputbuffer, qsos[qso_index], 81);
 
 			qso_index++;
 
-			if (strstr(s_inputbuffer, hiscall) != 0) {
+			if (strstr(s_inputbuffer, hiscall) != 0)
+			{
 				strcpy(searchresult[srch_index],s_inputbuffer);
 				searchresult[srch_index][80]='\0';
 
@@ -130,7 +145,8 @@ strcat(callmaster_location, "/callmaster ") ;
 
 				s_inputbuffer[0] = '\0';
 			}
-			else s_inputbuffer[0] = '\0';
+			else
+				s_inputbuffer[0] = '\0';
 		}
  		s_inputbuffer[0] = '\0';
  //
@@ -156,7 +172,8 @@ strcat(callmaster_location, "/callmaster ") ;
 
 		attron(COLOR_PAIR(7) | A_STANDOUT);
 
-		for (j =  2;  j <= 7; j++){
+		for (j =  2;  j <= 7; j++)
+		{
 			mvprintw(j, 42, "                                     ");
 		}
 			mvprintw(2, 42, " 10");
@@ -166,27 +183,35 @@ strcat(callmaster_location, "/callmaster ") ;
 			mvprintw(6, 42, " 80");
 			mvprintw(7, 42, "160");
 
-		attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+			attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
 
 	    	s_inputbuffer[0] = '\0';
 
 
 		k = 0;
 
-		for (r_index = 0; r_index < srch_index; r_index++){
+		for (r_index = 0; r_index < srch_index; r_index++)
+		{
 			strcpy(s_inputbuffer, result[r_index]);
 			s_inputbuffer[37] = '\0';
 
-			if((hiscall[0] == s_inputbuffer[12]) && (strlen(hiscall) >= 3 && (s_inputbuffer[12+strlen(hiscall)] == ' '))){
-
-				if ((strncmp(band[bandinx],  s_inputbuffer,  3) == 0) || (qso_once == 1)){
-
-					if (mixedmode == 0){
+			if((hiscall[0] == s_inputbuffer[12]) &&
+				(strlen(hiscall) >= 3 &&
+				(s_inputbuffer[12+strlen(hiscall)] == ' ')))
+				{
+				if ((strncmp(band[bandinx],  s_inputbuffer,  3) == 0) || (qso_once == 1))
+				{
+					if (mixedmode == 0)
+					{
 						attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
 						dupe  = ISDUPE;
 						beep();
-					} else {
-						if (((s_inputbuffer[3]=='C') && (trxmode == CWMODE)) || ((s_inputbuffer[3]== 'S') && (trxmode == SSBMODE))) {
+					} else
+					{
+						if (((s_inputbuffer[3]=='C') &&
+							(trxmode == CWMODE)) ||
+							((s_inputbuffer[3]== 'S') && (trxmode == SSBMODE)))
+						{
 							attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
 							dupe  = ISDUPE;
 							beep();
@@ -208,34 +233,34 @@ strcat(callmaster_location, "/callmaster ") ;
 							if (s_inputbuffer[1] == '6')
 							    j = 7;
 
-							if (j != 8)  {
+							if (j != 8)
+							{
 								mvprintw(j ,42, "%s", s_inputbuffer);
-							 }
-
-							if (cqww == 1){
+							}
 
+							if ((cqww == 1)||(wazmult==1)||(itumult==1))
+							{
 								z = 0;
-
-								if (strlen(s_inputbuffer) >= 24) {
-									strncpy(zonebuffer, s_inputbuffer + 25, 2);
+								if (strlen(s_inputbuffer) >= 24)
+								{
+                                    strncpy(zonebuffer, s_inputbuffer + 25, 2);
 									zonebuffer[2] = '\0';
 									z1 = zone_nr(zonebuffer);
+							    } else
+									z = zone_nr(zone_export);
 
-								} else  {
-
-										z = zone_nr(zone_export);
-								}
-                                 					if (z1 != 0)
-                                 						z = z1;
+								if (z1 != 0) z = z1;
 							 }
-							attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
 
-							if((partials == 1) &&  (strlen(hiscall) >= 2)){
+              					attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+
+							if((partials == 1) &&  (strlen(hiscall) >= 2))
+							{
 								if(strlen(s_inputbuffer) != 0)
 									strncpy(s_inputbuffercpy,  s_inputbuffer+12,6);
-									if(s_inputbuffercpy[5] == ' ')
+								if(s_inputbuffercpy[5] == ' ')
 										s_inputbuffercpy[5] = '\0';
-									if(s_inputbuffercpy[4] == ' ')
+								if(s_inputbuffercpy[4] == ' ')
 										s_inputbuffercpy[4] = '\0';
 							}
 
@@ -248,37 +273,40 @@ strcat(callmaster_location, "/callmaster ") ;
 		attroff(A_STANDOUT);
         		strncpy(s_inputbuffer,datalines[countrynr], 28);
 
-		for (i=0 ;  i <= 27 ; i++){
+		for (i=0 ;  i <= 27 ; i++)
+		{
 
-			if (s_inputbuffer[i] ==  ':'){
+			if (s_inputbuffer[i] ==  ':')
+			{
         				s_inputbuffer[i] =  ' ';
         				break;
-        			}
-        		}
+        	}
+        }
 
 
-        if (cqww == 1){
+        if ((cqww == 1)||(wazmult==1)||(itumult==1)){
 
 			if (z == 0){
 				if (strlen(zone_fix) > 1) {
-
 					strncpy(zonebuffer, zone_fix,2);
-
 				} else
 					strncpy(zonebuffer, zone_export,2);
 
 				zonebuffer[2] = '\0';
          			z = zone_nr(zonebuffer);
-			}
+      }
         }
 
         s_inputbuffer[28]='\0';
 
-        attron(COLOR_PAIR(COLOR_WHITE));
+        attron(COLOR_PAIR(COLOR_YELLOW));
 
 	mvprintw(8, 47, s_inputbuffer);
 	mvhline(8,  47 +  i, ACS_HLINE, 26 - i);
-	mvprintw(8, 73, zonebuffer);
+if (itumult!=1)
+   mvprintw(8, 73, "%s",zonebuffer);
+else
+  mvprintw(8, 69, "ITU:%s",zonebuffer);
 
         s_inputbuffer[0] = '\0';
 
@@ -315,7 +343,7 @@ strcat(callmaster_location, "/callmaster ") ;
 			mvprintw(7, 77, "C");
 			}
 	}
-	if(cqww == 1){
+	if((cqww == 1)||(wazmult==1)||(itumult==1)){
 		if ((zones[z] & BAND10 ) != 0){
 			mvprintw(2, 78, "Z");
 			}
@@ -336,7 +364,8 @@ strcat(callmaster_location, "/callmaster ") ;
 			}
 	}
 
-	if (pacc_pa_flg == 1){
+	if (pacc_pa_flg == 1)
+	{
 		
 		getpx(hiscall);
 		
@@ -569,9 +598,11 @@ strcat(callmaster_location, "/callmaster ") ;
 
 //  master.dta code
 
-	if(partials==1){
+	if(partials==1)
+	{
 
-		if(bigpartlist == 0)  {
+		if(bigpartlist == 0)
+		{
 
 			j=0;
 
@@ -582,15 +613,24 @@ strcat(callmaster_location, "/callmaster ") ;
 
 			mvprintw(13,0, " ??");
 
-			for (m =0; m < max_callmastercalls;  m++) {
+			for (m =0; m < max_callmastercalls;  m++)
+			{
 
-			   	if(strlen(callmasterarray[m]) >=2) {
+			   	if(strlen(callmasterarray[m]) >=2)
+				{
 
 					tmpstr = strstr(callmasterarray[m],hiscall);
 
-					if (tmpstr != NULL) {
-						if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
-						else attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+					if (tmpstr != NULL)
+					{
+						if (use_rxvt == 0)
+							attron(COLOR_PAIR(COLOR_WHITE
+								| A_BOLD
+								|A_STANDOUT));
+
+						else
+							attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+
 						mvprintw(13,j, "%s  ",callmasterarray[m]);
 
 						if(strlen(s_inputbuffercpy) == 0)
@@ -607,29 +647,38 @@ strcat(callmaster_location, "/callmaster ") ;
 
 
 			}
-		}   else {
+		}   else
+		{
 			l = 0;
 			j = 0;
 
-			if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
-			else attron(COLOR_PAIR(COLOR_WHITE  | A_STANDOUT));
+			if (use_rxvt == 0)
+				attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+			else
+				attron(COLOR_PAIR(COLOR_WHITE  | A_STANDOUT));
 
-			for(j = 0; j < 9; j++) {
+			for(j = 0; j < 9; j++)
+			{
 				mvprintw(15+j, 38, "                                         ");
 				refresh();
 			}
 
 			j = 0;
 
-			for (m =0; m < max_callmastercalls;  m++) {
+			for (m =0; m < max_callmastercalls;  m++)
+			{
 
-			   	if(strlen(callmasterarray[m]) >=2) {
+			   	if(strlen(callmasterarray[m]) >=2)
+				{
 
 					tmpstr = strstr(callmasterarray[m],hiscall);
 
-					if (tmpstr != NULL) {
-						if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
-						else attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+					if (tmpstr != NULL)
+					{
+						if (use_rxvt == 0)
+							attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+						else
+							attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
 						mvprintw(15+l,38+j, "%s  ",callmasterarray[m]);
 
 						if(strlen(s_inputbuffercpy) == 0)
@@ -638,7 +687,8 @@ strcat(callmaster_location, "/callmaster ") ;
 
 						j=j+7;
 
-						if(j>=42) {
+						if(j>=42)
+						{
 							l ++;
 							j = 0;
 
@@ -655,18 +705,19 @@ strcat(callmaster_location, "/callmaster ") ;
 
 		}
 
-			if ((j <= 13)&& (l == 0)&& (use_part == 1)&&(block_part == 0)) {
-
+			if ((j <= 13)&& (l == 0)&& (use_part == 1)&&(block_part == 0))
+			{
 					if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_GREEN | A_BOLD | A_STANDOUT));
 					else attron(COLOR_PAIR(COLOR_GREEN | A_STANDOUT));
 
 					mvprintw(13,0, s_inputbuffercpy);
 			}
 
-			if((block_part == 0) && (use_part == 1) && (j <= 13)&& (l == 0)&& (strlen(s_inputbuffercpy) > strlen(hiscall)) ){
+			if((block_part == 0) && (use_part == 1) && (j <= 13)&& (l == 0)&&
+				(strlen(s_inputbuffercpy) > strlen(hiscall)) )
+			{
 
 					strcpy(hiscall, s_inputbuffercpy);
-//					block_part = 1;
 					beep();
 
 			}
@@ -674,55 +725,73 @@ strcat(callmaster_location, "/callmaster ") ;
 
 	}
 
-	if (dupe == NODUPE && arrlss == 1)	 r_multiplierinfo();
+	if (dupe == NODUPE && arrlss == 1)
+		r_multiplierinfo();
 
-	if (dupe == ISDUPE){
+	if (dupe == ISDUPE)
+	{
 	    		isdupe=1;		// LZ3NY auto-b4 patch
 				attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
 				mvprintw(12, 29, hiscall);
 				refresh();
 				usleep(100000);
 	}
-	else printcall();
+	else
+		printcall();
 
 	}
 
 
  	 return(0);
- }
+}
 
 // --------------------------------------------load callmaster ------------------
  int load_callmaster(void) {
 
- extern char callmasterarray[28000][9];
+ extern char callmasterarray[MAX_CALLMASTER][9];
  extern int arrlss;
 
  FILE *cfp ;
  char callmaster_location[80];
  char s_inputbuffer[186] =  "";
- int count = 0;
+ long int count = 0;
+ int file_ok = 0;
 
-strcpy(callmaster_location, PACKAGE_DATA_DIR) ;
-strcat(callmaster_location, "/callmaster") ;
+		strcpy(callmaster_location, "callmaster");
+		if ( (cfp = fopen(callmaster_location,"r"))  == NULL)
+		{
+			callmaster_location[0]='\0';
+			strcpy(callmaster_location, PACKAGE_DATA_DIR) ;
+			strcat(callmaster_location, "/callmaster") ;
 
 
-			if  ( (cfp = fopen(callmaster_location,"r"))  == NULL){
+			if  ( (cfp = fopen(callmaster_location,"r"))  == NULL)
+			{
 				mvprintw(24,0,  "Error opening callmaster file.\n");
 				refresh();
 				sleep(2);
-			}  else {
+			}
+			else file_ok = 1;
+		}
+			else file_ok = 1;
+
+			if (file_ok == 1)
+			{
 
 				count = 0;
 
-				while  (!feof(cfp) ) {
+				while  (!feof(cfp) )
+				{
 					s_inputbuffer[0]='\0';
 					fgets (s_inputbuffer, 85,  cfp);
 
-					if (arrlss == 1) {
+					if (arrlss == 1)
+					{
 
 						if((s_inputbuffer[0] == 'A') || (s_inputbuffer[0] == 'K')
 								|| (s_inputbuffer[0] == 'W') || (s_inputbuffer[0] == 'V')
-								|| (s_inputbuffer[0] == 'C') || (s_inputbuffer[0] == 'N')) {
+								|| (s_inputbuffer[0] == 'C') || (s_inputbuffer[0] == 'N'))
+								{
 							s_inputbuffer[strlen(s_inputbuffer)-1]='\0';
 
 							s_inputbuffer[9]='\0';
@@ -730,7 +799,8 @@ strcat(callmaster_location, "/callmaster") ;
 							count++;
 						}
 
-					} else {
+					} else
+					{
 
 						if(strlen(s_inputbuffer)>0)
 							s_inputbuffer[strlen(s_inputbuffer)-1]='\0';
@@ -747,16 +817,15 @@ strcat(callmaster_location, "/callmaster") ;
 				fclose(cfp);
 			}
 
+
   return(count);
 }
 // -------------------------------------------------------------------------------
-char multsfile[40] = "";
+char multsfile[120] = "";		// global... (to be fixed)
 // ----------------------------------------------load mults ------------------------
 int load_multipliers(void) {
 
 extern char mults_possible[MAX_MULTS][12];
-extern int arrlss;
-extern int universal;
 extern char multiplierlist[];
 
  FILE *cfp ;
@@ -768,7 +837,15 @@ extern char multiplierlist[];
 				mults_possible[i][0] = '\0';
 			}
 
-			strncpy(multsfile , multiplierlist, strlen(multiplierlist)-1);
+			if (strlen(multiplierlist) != 0)
+				strncpy(multsfile , multiplierlist, strlen(multiplierlist)-1);
+			else {
+				mvprintw(9,0,  "No multiplier file specified, exiting.. !!\n");
+				refresh();
+				sleep(5);
+				exit(1);
+			}
+
 			if  ( (cfp = fopen(multsfile , "r"))  == NULL){
 				mvprintw(9,0,  "Error opening multiplier file %s.\n", multsfile);
 				refresh();
