@@ -59,7 +59,7 @@ static struct timeval *socktimeval = NULL;
 static struct timeval *selecttimeval = NULL;
 static struct sockaddr_in udp_peer;
 static int udpport = 0;
-static int peerlen = 0;
+static unsigned int peerlen = 0;
 int udp_socket = -1;
 
 static fd_set readfds, openfds;
@@ -302,7 +302,8 @@ int startup_udp(int portnum)
 
 int recvline(int *fd, char *buf, int buflen)
 {
-    int len, ns, i;
+    unsigned int len;
+    int ns, i;
     struct sockaddr_in client;
     char *nl;
 
@@ -480,7 +481,6 @@ int startcliaddr(int family, unsigned long int addr, unsigned short int portnum)
 
 	int s;
     struct sockaddr_in sin;
-	char socketbuffer[512];	// debug
 
     initialize();
     memset(&sin, 0, sizeof(sin));
