@@ -43,6 +43,9 @@
 #define LPT_KEYER 1
 #define COM1_KEYER 2
 #define NET_KEYER 3
+#define MFJ1278_KEYER 4
+#define ORION_KEYER 5
+#define K2_KEYER 6
 
 #define SINGLE 0        /* single op */
 #define MULTI 1         /* multi op / single tx */
@@ -95,24 +98,29 @@
 #define BANDINDEX_12 7
 #define BANDINDEX_10 8
 
+#define NBANDS 9	// not yet used everywhere, many places have hardcode 9 (or 8, being the maximum band index)
+
 #define DUPECOLOR 5
 #define NORMCOLOR 4
 #define ISDUPE 1
 #define NODUPE 0
 
-#define  MAX_QSOS 10000           /* internal qso array */
-#define  MAX_DATALINES 350   /* from ctydb.dat  */
-#define  MAX_DBLINES 3000    /* exceptioncalls from ctydb.dat  */
+#define  MAX_QSOS 15000           /* internal qso array */
+#define  MAX_DATALINES 700   /* from ctydb.dat  */
+#define  MAX_DBLINES 6000    /* exceptioncalls from ctydb.dat  */
 #define  MAX_CALLS 5000      /*  max nr of calls in dupe array */
-#define  MAX_MULTS 150        /* max nr of mults in mults array */
+#define  MAX_MULTS 800        /* max nr of mults in mults array */
+#define	MAX_SPOTS 200		/* max nr. of spots in spotarray */
+#define MAX_CALLMASTER 40000 /* max number of calls in callmaster array */
 
-#define  MAX_COMMANDS 120
+#define  MAX_COMMANDS 150
 
 #define EDITOR_JOE 0
 #define EDITOR_VI 1
 #define EDITOR_E3 2
+#define EDITOR_MC 3
 
-#define  CW_SPEEDS	"06121416182022242628303642485054576063666972"
+#define  CW_SPEEDS	"06121416182022242628303234363840424446485060"
 #endif
 
 #if defined (TLN_LOGLINE)
