@@ -34,6 +34,7 @@
 	extern int other_flg;
 	extern int wysiwyg_multi;
 	extern int wysiwyg_once;
+	extern int serial_grid4_mult;
 	extern char mycqzone[];
 	extern char exchange[];
 	extern int cqwwm2;
@@ -45,7 +46,6 @@
 	char buf[181];
 	char buffer[82]= "";
     	char standardexchange[70] = "";
-    	char ssa_mt_exchange[30];
 	
 	FILE *fp1,  *fp2;
 
@@ -241,10 +241,10 @@ exchange given
 					strncat(buffer, exchange, 2);
 					strcat (buffer, "     ");
 
-				}else if (strcmp (whichcontest, "ssa_mt") == 0) {
+				}else if (serial_grid4_mult == 1) {
 					strcat (buffer, "  ");
 					sprintf(buffer + 49, "%s", buf+24);
-					sprintf(buffer + 53, "%s", standardexchange + 1);
+					sprintf(buffer + 52, "%s", standardexchange + 1);
 
 					strcat (buffer, "                ");
 					sprintf(buffer + 60, "%s          ", buf+29);
@@ -271,14 +271,13 @@ rprt given
 				else
 					strcat(buffer, "599 ");
 
-				if (strcmp (whichcontest, "ssa_mt") == 0) {
+				if (serial_grid4_mult == 1) {
 					char ssa_mt_exchange[30];
 					int i=0, j=0, k = 0;
 //					strncat(buffer, buf+54, 9);  // tbf for all contests? RC
 					strcat(buffer, "                      ");
 
-					sprintf(buffer + 79, "%03d    ", atoi(buf+54));
-
+					sprintf(buffer + 79, "%03d   ", atoi(buf+54));
 
 					for (i=0; i < 12; i++) {
 						if (isalpha(buf[54+i])){
@@ -298,19 +297,6 @@ rprt given
 						}
 					}
 
-/*					for (i = 0; i < 12; i++) {
-						if (isalnum(buf[54 + i])) {				// no white space
-							ssa_mt_exchange[j] = buf[54 + i];
-							j++;
-						}else {
-							if ( i > 0 && isspace(buf[54 + i - 1]))
-							{// 2 spaces
-								ssa_mt_exchange[j] = '\0';
-								break;
-							}
-						}
-					}
-*/
 					sprintf(buffer+83, "%s        ", ssa_mt_exchange);
 					sprintf(buffer+90, "%s", "0");
 				}
